@@ -138,6 +138,17 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 		m_ui.AudioMetroOffsetSpinBox->setDeltaValue(true);
 	}
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 2, 0)
+	// Some conveniency cleaner helpers...
+	m_ui.SessionTemplatePathComboBox->lineEdit()->setClearButtonEnabled(true);
+	m_ui.MetroBarFilenameComboBox->lineEdit()->setClearButtonEnabled(true);
+	m_ui.MetroBeatFilenameComboBox->lineEdit()->setClearButtonEnabled(true);
+	m_ui.MessagesLogPathComboBox->lineEdit()->setClearButtonEnabled(true);
+	m_ui.PluginPathComboBox->lineEdit()->setClearButtonEnabled(true);
+	m_ui.PluginBlacklistComboBox->lineEdit()->setClearButtonEnabled(true);
+	m_ui.Lv2PresetDirComboBox->lineEdit()->setClearButtonEnabled(true);
+#endif
+
 	// Populate the session format combo-box.
 	initSessionFormats();
 
@@ -157,7 +168,7 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 	}
 
 	// Populate the MIDI capture quantize combo-box.
-	const QIcon snapIcon(":/images/itemBeat.png");
+	const QIcon& snapIcon = QIcon::fromTheme("itemBeat");
 	const QStringList& snapItems = qtractorTimeScale::snapItems();
 	QStringListIterator snapIter(snapItems);
 	m_ui.MidiCaptureQuantizeComboBox->clear();
@@ -165,7 +176,7 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 //	snapIter.toFront();
 	if (snapIter.hasNext())
 		m_ui.MidiCaptureQuantizeComboBox->addItem(
-			QIcon(":/images/itemNone.png"), snapIter.next());
+			QIcon::fromTheme("itemNone"), snapIter.next());
 	while (snapIter.hasNext())
 		m_ui.MidiCaptureQuantizeComboBox->addItem(snapIcon, snapIter.next());
 //	m_ui.MidiCaptureQuantizeComboBox->insertItems(0, items);
@@ -447,6 +458,12 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 	QObject::connect(m_ui.CustomStyleSheetToolButton,
 		SIGNAL(clicked()),
 		SLOT(chooseCustomStyleSheet()));
+	QObject::connect(m_ui.CustomIconsThemeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(changed()));
+	QObject::connect(m_ui.CustomIconsThemeToolButton,
+		SIGNAL(clicked()),
+		SLOT(chooseCustomIconsTheme()));
 	QObject::connect(m_ui.AudioMeterLevelComboBox,
 		SIGNAL(activated(int)),
 		SLOT(changeAudioMeterLevel(int)));
@@ -586,6 +603,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_pOptions->loadComboBoxHistory(m_ui.MetroBarFilenameComboBox);
 	m_pOptions->loadComboBoxHistory(m_ui.MetroBeatFilenameComboBox);
 	m_pOptions->loadComboBoxFileHistory(m_ui.CustomStyleSheetComboBox);
+	m_pOptions->loadComboBoxFileHistory(m_ui.CustomIconsThemeComboBox);
 	m_pOptions->loadComboBoxHistory(m_ui.PluginPathComboBox);
 	m_pOptions->loadComboBoxHistory(m_ui.MessagesLogPathComboBox);
 	m_pOptions->loadComboBoxHistory(m_ui.SessionTemplatePathComboBox);
@@ -723,6 +741,9 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_pOptions->setComboBoxCurrentFile(
 		m_ui.CustomStyleSheetComboBox,
 		m_pOptions->sCustomStyleSheet);
+	m_pOptions->setComboBoxCurrentFile(
+		m_ui.CustomIconsThemeComboBox,
+		m_pOptions->sCustomIconsTheme);
 
 	// Load Display options...
 	QFont font;
@@ -1012,6 +1033,7 @@ void qtractorOptionsForm::accept (void)
 		else
 			m_pOptions->sCustomStyleTheme.clear();
 		m_pOptions->sCustomStyleSheet = m_pOptions->comboBoxCurrentFile(m_ui.CustomStyleSheetComboBox);
+		m_pOptions->sCustomIconsTheme = m_pOptions->comboBoxCurrentFile(m_ui.CustomIconsThemeComboBox);
 		// Reset dirty flags.
 		qtractorPluginFactory *pPluginFactory
 			= qtractorPluginFactory::getInstance();
@@ -1059,6 +1081,7 @@ void qtractorOptionsForm::accept (void)
 	m_pOptions->saveComboBoxHistory(m_ui.MetroBarFilenameComboBox);
 	m_pOptions->saveComboBoxHistory(m_ui.MetroBeatFilenameComboBox);
 	m_pOptions->saveComboBoxFileHistory(m_ui.CustomStyleSheetComboBox);
+	m_pOptions->saveComboBoxFileHistory(m_ui.CustomIconsThemeComboBox);
 	m_pOptions->saveComboBoxHistory(m_ui.PluginPathComboBox);
 	m_pOptions->saveComboBoxHistory(m_ui.MessagesLogPathComboBox);
 	m_pOptions->saveComboBoxHistory(m_ui.SessionTemplatePathComboBox);
@@ -1316,14 +1339,65 @@ void qtractorOptionsForm::chooseCustomStyleSheet (void)
 		sFilename = fileDialog.selectedFiles().first();
 #endif
 
-	if (!sFilename.isEmpty()
-		&& m_pOptions->setComboBoxCurrentFile(
+	if (sFilename.isEmpty())
+		return;
+
+	if (m_pOptions->setComboBoxCurrentFile(
 			m_ui.CustomStyleSheetComboBox, sFilename)) {
 		changed();
 	}
 }
 
 
+// Custom icons theme (directory) chooser.
+void qtractorOptionsForm::chooseCustomIconsTheme (void)
+{
+	if (m_pOptions == nullptr)
+		return;
+
+	QString sIconsDir = m_ui.CustomIconsThemeComboBox->currentText();
+
+	const QString& sTitle
+		= tr("Icons Theme Directory");
+
+	QWidget *pParentWidget = nullptr;
+	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
+	if (m_pOptions->bDontUseNativeDialogs) {
+		options |= QFileDialog::DontUseNativeDialog;
+		pParentWidget = QWidget::window();
+	}
+#if 1// QT_VERSION < QT_VERSION_CHECK(4, 4, 0)
+	// Ask for the directory...
+	sIconsDir = QFileDialog::getExistingDirectory(pParentWidget,
+		sTitle, sIconsDir, options);
+#else
+	// Construct open-directory dialog...
+	QFileDialog fileDialog(pParentWidget, sTitle, sIconsDir);
+	// Set proper open-file modes...
+	fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
+	fileDialog.setFileMode(QFileDialog::DirectoryOnly);
+	// Stuff sidebar...
+	QList<QUrl> urls(fileDialog.sidebarUrls());
+	urls.append(QUrl::fromLocalFile(m_pOptions->sIconsDir));
+	fileDialog.setSidebarUrls(urls);
+	fileDialog.setOptions(options);
+	// Show dialog...
+	if (fileDialog.exec())
+		sLv2PresetDir = fileDialog.selectedFiles().first();
+#endif
+
+	if (sIconsDir.isEmpty())
+		return;
+
+	// TODO: Make sure the chosen directory has some image files...
+	//
+	if (m_pOptions->setComboBoxCurrentFile(
+			m_ui.CustomIconsThemeComboBox, sIconsDir)) {
+		changed();
+	}
+}
+
+
 // Audio meter level index change.
 void qtractorOptionsForm::changeAudioMeterLevel ( int iColor )
 {
